# HyTra
**Hy**pergraph **Tra**nsversals: a project to study, and to employ in applications, algorithms for computing the minimal transversals of a hypergraph or, equivalently, to dualize monotone Boolean functions (or, equivalently, lots of things). Currently at version: 0.0.3 alpha 1.

This project has _no connection whatsoever_ to the Python-based LISP dialect called Hy. Hypergraphs had their name well established looooong before the birth of that programming language. 

Written in standard Python: initially Python 2, later adjusted to be compatible with both Python 2 and 3. Compatibility with Python 2 is likely to be lost in the near future.

An earlier version of this software was written mid 2007 as ancillary classes for several exploratory developments on mining closed sets and association rules; of these, only https://github.com/balqui/yacaree remains active. Initially, HyTra was set up with, essentially, these 2007 programs; its mid-term purpose is to enjoy an independent life as a platform for testing and evaluating the efficiency of hypergraph transversal algorithms, of which there are several out there by now. However, it starts as rather simple implementations both of the hypergraphs and of the transversal computation.
